@@ -25,18 +25,6 @@ impl From<EpisodeLinkFromImdb> for EpisodeLink {
 	}
 }
 
-impl EpisodeLink {
-	#[cfg(test)]
-	pub(crate) fn new(imdb_id: u32, series_imdb_id: u32, season: Option<u16>, episode: Option<u16>) -> Self {
-		Self{
-			imdb_id,
-			series_imdb_id,
-			season,
-			episode
-		}
-	}
-}
-
 #[derive(Debug, Deserialize, Eq, PartialEq)]
 pub(crate) struct EpisodeLinkFromImdb {
 	#[serde(rename = "tconst", deserialize_with = "crate::util::parse_imdb_id")]
