@@ -1,8 +1,12 @@
 use std::cmp::Ordering;
 use std::convert::TryFrom;
+#[cfg(test)]
+use std::convert::TryInto;
 
+use arrayvec::ArrayVec;
 use smartstring::alias::String;
 
+use crate::genre::Genre;
 use crate::EpisodeLink;
 use crate::Error;
 use crate::Title;
@@ -17,7 +21,7 @@ pub struct Show {
 	pub start_year: u16,
 	pub end_year: Option<u16>,
 	pub runtime_minutes: Option<u16>,
-	pub genres: Vec<String>,
+	pub genres: ArrayVec<Genre, 3>,
 	pub episodes: Vec<Episode>
 }
 
@@ -39,7 +43,7 @@ impl std::fmt::Debug for Show /* {{{ */ {
 impl Show {
 	#[cfg(test)]
 	#[allow(clippy::too_many_arguments)] // Only a convenience function for tests; this is fine
-	pub(crate) fn new(imdb_id: u32, title: &str, is_adult: bool, start_year: u16, end_year: Option<u16>, runtime_minutes: Option<u16>, genres: &[&str], episodes: &[Episode]) -> Self /* {{{ */ {
+	pub(crate) fn new(imdb_id: u32, title: &str, is_adult: bool, start_year: u16, end_year: Option<u16>, runtime_minutes: Option<u16>, genres: &[Genre], episodes: &[Episode]) -> Self /* {{{ */ {
 		Self{
 			imdb_id,
 			title: String::from(title),
@@ -47,7 +51,7 @@ impl Show {
 			start_year,
 			end_year,
 			runtime_minutes,
-			genres: genres.iter().map(|s| String::from(*s)).collect(),
+			genres: genres.try_into().unwrap(),
 			episodes: episodes.to_vec()
 		}
 	} // }}}
